summaryrefslogtreecommitdiff
path: root/gcc/config/i386/gas.h
diff options
context:
space:
mode:
authorjrv <jrv@138bc75d-0d04-0410-961f-82ee72b054a4>1992-12-28 02:28:53 +0000
committerjrv <jrv@138bc75d-0d04-0410-961f-82ee72b054a4>1992-12-28 02:28:53 +0000
commit16ece14087e3be808d3275bd52e8641e6b5cb90f (patch)
tree1bc7df66ba0b3e7379a3ece6ed47cf1b4f426022 /gcc/config/i386/gas.h
parent34caabe915d9dce974b6ab5e19ef054f490a00c2 (diff)
downloadgcc-16ece14087e3be808d3275bd52e8641e6b5cb90f.tar.gz
Renamed from i386gas.h.
Use new file names for included 386 files. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@2940 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/config/i386/gas.h')
-rw-r--r--gcc/config/i386/gas.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/gcc/config/i386/gas.h b/gcc/config/i386/gas.h
index 141a857ec46..be1118f50bf 100644
--- a/gcc/config/i386/gas.h
+++ b/gcc/config/i386/gas.h
@@ -17,13 +17,13 @@ You should have received a copy of the GNU General Public License
along with GNU CC; see the file COPYING. If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
/* Note that seq386gas.h is a GAS configuration that does not use this
file. */
-#include "i386.h"
+#include "i386/386.h"
#ifndef YES_UNDERSCORES
/* Define this now, because bsd386.h tests it. */
#define NO_UNDERSCORES
#endif
@@ -43,9 +43,9 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
* people who want both form will have to compile twice.
*/
#include "bsd386.h"
/* these come from bsd386.h, but are specific to sequent */
#undef DBX_NO_XREFS
#undef DBX_CONTIN_LENGTH
@@ -127,7 +127,7 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
count is in %cl. Some assemblers require %cl as an argument;
some don't.
- GAS requires the %cl argument, so override unx386.h. */
+ GAS requires the %cl argument, so override i386/unix.h. */
#undef AS3_SHIFT_DOUBLE
#define AS3_SHIFT_DOUBLE(a,b,c,d) AS3 (a,b,c,d)
@@ -17,13 +17,13 @@ You should have received a copy of the GNU General Public License
along with GNU CC; see the file COPYING. If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
-/* Note that seq386gas.h is a GAS configuration that does not use this
+/* Note that i386/seq-gas.h is a GAS configuration that does not use this
file. */
@@ -17,13 +17,13 @@ You should have received a copy of the GNU General Public License
#ifndef YES_UNDERSCORES
-/* Define this now, because bsd386.h tests it. */
+/* Define this now, because i386/bsd.h tests it. */
#define NO_UNDERSCORES
#endif
@@ -43,9 +43,9 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. */
* people who want both form will have to compile twice.
*/
-#include "bsd386.h"
+#include "i386/bsd.h"
-/* these come from bsd386.h, but are specific to sequent */
+/* these come from i386/bsd.h, but are specific to sequent */
#undef DBX_NO_XREFS
#undef DBX_CONTIN_LENGTH